@@ -8,7 +8,7 @@ use std::collections::LinkedList;
 use std::rc::Rc;
 
 /// Main type of an Abstract Syntax Tree.
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Debug, PartialEq)]
 pub enum AST {
     Assert {
         expression: Box<AST>,
@@ -50,7 +50,7 @@ pub enum AST {
         position: Position,
     },
     LetIn {
-        bindings: LinkedList<Bind>,
+        bindings: LinkedList<Binding>,
         target:   Box<AST>,
         position: Position,
     },
@@ -59,7 +59,7 @@ pub enum AST {
         position: Position,
     },
     Map {
-        bindings:  LinkedList<Bind>,
+        bindings:  LinkedList<Binding>,
         recursive: bool,
         position:  Position,
     },
@@ -99,13 +99,15 @@ pub enum AST {
 
     // Temporary containers
     #[doc(hidden)]
+    __,
+    #[doc(hidden)]
     __Attribute(Attribute),
     #[doc(hidden)]
     __Attributes(LinkedList<Attribute>),
     #[doc(hidden)]
     __AttributePath(AttributePath),
     #[doc(hidden)]
-    __Bindings(LinkedList<Bind>),
+    __Bindings(LinkedList<Binding>),
     #[doc(hidden)]
     __FunctionArgument(FunctionArgument),
     #[doc(hidden)]
@@ -116,24 +118,24 @@ pub enum AST {
     __Lexeme(Rc<Lexeme>),
 }
 
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Debug, PartialEq)]
 pub enum Attribute {
     Raw { content: String, position: Position },
     Expression { expression: Box<AST> },
 }
 
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Debug, PartialEq)]
 pub struct AttributePath {
     pub attributes: LinkedList<Attribute>,
 }
 
-#[derive(Clone, Debug, PartialEq)]
-pub enum Bind {
+#[derive(Debug, PartialEq)]
+pub enum Binding {
     KeyValue(AttributePath, Box<AST>),
     Inherit(Option<Box<AST>>, LinkedList<Attribute>),
 }
 
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Debug, PartialEq)]
 pub enum BinaryOperator {
     Addition,
     Concatenation,
@@ -152,25 +154,25 @@ pub enum BinaryOperator {
     Update,
 }
 
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Debug, PartialEq)]
 pub struct FunctionArgument {
     pub identifier: String,
     pub default:    Option<Box<AST>>,
 }
 
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Debug, PartialEq)]
 pub struct FunctionArguments {
     pub arguments: LinkedList<FunctionArgument>,
     pub ellipsis:  bool,
 }
 
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Debug, PartialEq)]
 pub enum StringPart {
     Raw { content: String, position: Position },
     Expression { expression: Box<AST> },
 }
 
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Debug, PartialEq)]
 pub enum UnaryOperator {
     Not,
     Negate,
